==> SugarCE-6.2.0.zip: SugarCE-Full-6.2.0/modules/Cases/language/en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/

/*********************************************************************************

 * Description:  Defines the English language pack for the base application.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = array (
	'ERR_DELETE_RECORD'					=> 'You must specify a record number to delete the account.',

	'LBL_ACCOUNT_ID'					=> 'Account ID',
	'LBL_ACCOUNT_NAME'					=> 'Account Name:',
	'LBL_ACCOUNTS_SUBPANEL_TITLE'		=> 'Accounts',
	'LBL_ACTIVITIES_SUBPANEL_TITLE'		=> 'Activities',
	'LBL_ATTACH_NOTE' 					=> 'Attach Note',
	'LBL_BUGS_SUBPANEL_TITLE'			=> 'Bugs',
	'LBL_CASE_NUMBER'					=> 'Case Number:',
	'LBL_CASE_SUBJECT'					=> 'Case Subject:',
	'LBL_CASE'							=> 'Case:',
	'LBL_CONTACT_CASE_TITLE'			=> 'Contact-Case:',
	'LBL_CONTACT_NAME'					=> 'Contact Name:',
	'LBL_CONTACT_ROLE'					=> 'Role:',
	'LBL_CONTACTS_SUBPANEL_TITLE'		=> 'Contacts',
	'LBL_DEFAULT_SUBPANEL_TITLE'		=> 'Cases',
	'LBL_DESCRIPTION'					=> 'Description:',
	'LBL_FILENANE_ATTACHMENT' 			=> 'File Attachment',	
	'LBL_HISTORY_SUBPANEL_TITLE'		=> 'History',
	'LBL_INVITEE'						=> 'Contacts',
	'LBL_MEMBER_OF'						=> 'Account',
	'LBL_MODULE_NAME'					=> 'Cases',
	'LBL_MODULE_TITLE'					=> 'Cases: Home',
	'LBL_NEW_FORM_TITLE'				=> 'New Case',
	'LBL_NUMBER'						=> 'Number:',
	'LBL_PRIORITY'						=> 'Priority:',
	'LBL_PROJECTS_SUBPANEL_TITLE' 		=> 'Projects',
	'LBL_DOCUMENTS_SUBPANEL_TITLE' 		=> 'Documents',
	'LBL_RESOLUTION'					=> 'Resolution:',
	'LBL_SEARCH_FORM_TITLE'				=> 'Case Search',
	'LBL_STATUS'						=> 'Status:',
	'LBL_SUBJECT'						=> 'Subject:',
	'LBL_SYSTEM_ID'						=> 'System ID',
	'LBL_LIST_ASSIGNED_TO_NAME' 		=> 'Assigned User',
	'LBL_LIST_ACCOUNT_NAME'				=> 'Account Name',
	'LBL_LIST_ASSIGNED'					=> 'Assigned To',
	'LBL_LIST_CLOSE'					=> 'Close',
	'LBL_LIST_FORM_TITLE'				=> 'Case List',
	'LBL_LIST_LAST_MODIFIED'			=> 'Last Modified',
	'LBL_LIST_MY_CASES'					=> 'My Open Cases',
	'LBL_LIST_NUMBER'					=> 'Num.',
	'LBL_LIST_PRIORITY'					=> 'Priority',
	'LBL_LIST_STATUS'					=> 'Status',
	'LBL_LIST_SUBJECT'					=> 'Subject',
	'LBL_LIST_ASSIGNED_TO_NAME'   		=> 'Assigned User',

	'LNK_CASE_LIST'						=> 'View Cases',
	'LNK_NEW_CASE'						=> 'Create Case',
	'NTC_REMOVE_FROM_BUG_CONFIRMATION'	=> 'Are you sure you want to remove this case from the bug?',
	'NTC_REMOVE_INVITEE'				=> 'Are you sure you want to remove this contact from the case?',
	'LBL_LIST_DATE_CREATED'			=> 'Date Created',
	'LBL_ASSIGNED_TO_NAME' => 'Assigned to',
	'LBL_TYPE'=>'Type',
	'LBL_WORK_LOG'=>'Work Log',
	'LNK_IMPORT_CASES' => 'Import Cases',

    'LBL_CREATED_USER' => 'Created User',
    'LBL_MODIFIED_USER' => 'Modified User',
    'LBL_PROJECT_SUBPANEL_TITLE' => 'Projects',
    'LBL_CASE_INFORMATION' => 'Case Overview',
);


?>

==> SugarCE-6.5.13.zip: SugarCE-Full-6.5.13/modules/Cases/language/en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2013 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/

/*********************************************************************************

 * Description:  Defines the English language pack for the base application.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = array (
	'ERR_DELETE_RECORD'					=> 'You must specify a record number to delete the account.',

	'LBL_ACCOUNT_ID'					=> 'Account ID',
	'LBL_ACCOUNT_NAME'					=> 'Account Name:',
	'LBL_ACCOUNTS_SUBPANEL_TITLE'		=> 'Accounts',
	'LBL_ACTIVITIES_SUBPANEL_TITLE'		=> 'Activities',
	'LBL_ATTACH_NOTE' 					=> 'Attach Note',
	'LBL_BUGS_SUBPANEL_TITLE'			=> 'Bugs',
	'LBL_CASE_NUMBER'					=> 'Case Number:',
	'LBL_CASE_SUBJECT'					=> 'Case Subject:',
	'LBL_CASE'							=> 'Case:',
	'LBL_CONTACT_CASE_TITLE'			=> 'Contact-Case:',
	'LBL_CONTACT_NAME'					=> 'Contact Name:',
	'LBL_CONTACT_ROLE'					=> 'Role:',
	'LBL_CONTACTS_SUBPANEL_TITLE'		=> 'Contacts',
	'LBL_DEFAULT_SUBPANEL_TITLE'		=> 'Cases',
	'LBL_DESCRIPTION'					=> 'Description:',
	'LBL_FILENANE_ATTACHMENT' 			=> 'File Attachment',	
	'LBL_HISTORY_SUBPANEL_TITLE'		=> 'History',
	'LBL_INVITEE'						=> 'Contacts',
	'LBL_MEMBER_OF'						=> 'Account',
	'LBL_MODULE_NAME'					=> 'Cases',
	'LBL_MODULE_TITLE'					=> 'Cases: Home',
	'LBL_NEW_FORM_TITLE'				=> 'New Case',
	'LBL_NUMBER'						=> 'Number:',
	'LBL_PRIORITY'						=> 'Priority:',
	'LBL_PROJECTS_SUBPANEL_TITLE' 		=> 'Projects',
	'LBL_DOCUMENTS_SUBPANEL_TITLE' 		=> 'Documents',
	'LBL_RESOLUTION'					=> 'Resolution:',
	'LBL_SEARCH_FORM_TITLE'				=> 'Case Search',
	'LBL_STATUS'						=> 'Status:',
	'LBL_SUBJECT'						=> 'Subject:',
	'LBL_SYSTEM_ID'						=> 'System ID',
	'LBL_LIST_ASSIGNED_TO_NAME' 		=> 'Assigned User',
	'LBL_LIST_ACCOUNT_NAME'				=> 'Account Name',
	'LBL_LIST_ASSIGNED'					=> 'Assigned To',
	'LBL_LIST_CLOSE'					=> 'Close',
	'LBL_LIST_FORM_TITLE'				=> 'Case List',
	'LBL_LIST_LAST_MODIFIED'			=> 'Last Modified',
	'LBL_LIST_MY_CASES'					=> 'My Open Cases',
	'LBL_LIST_NUMBER'					=> 'Num.',
	'LBL_LIST_PRIORITY'					=> 'Priority',
	'LBL_LIST_STATUS'					=> 'Status',
	'LBL_LIST_SUBJECT'					=> 'Subject',
	'LBL_LIST_ASSIGNED_TO_NAME'   		=> 'Assigned User',

	'LNK_CASE_LIST'						=> 'View Cases',
	'LNK_NEW_CASE'						=> 'Create Case',
	'NTC_REMOVE_FROM_BUG_CONFIRMATION'	=> 'Are you sure you want to remove this case from the bug?',
	'NTC_REMOVE_INVITEE'				=> 'Are you sure you want to remove this contact from the case?',
	'LBL_LIST_DATE_CREATED'			=> 'Date Created',
	'LBL_ASSIGNED_TO_NAME' => 'Assigned to',
	'LBL_TYPE'=>'Type',
	'LBL_WORK_LOG'=>'Work Log',
	'LNK_IMPORT_CASES' => 'Import Cases',

    'LBL_CREATED_USER' => 'Created User',
    'LBL_MODIFIED_USER' => 'Modified User',
    'LBL_PROJECT_SUBPANEL_TITLE' => 'Projects',
    'LBL_CASE_INFORMATION' => 'Overview',

    //For export labels
    'LBL_MODIFIED_BY_NAME_OWNER' => 'Modified By Name Owner',
    'LBL_MODIFIED_BY_NAME_MOD' => 'Modified By Name Mod',
    'LBL_CREATED_BY_NAME_OWNER' => 'Created By Name Owner',
    'LBL_CREATED_BY_NAME_MOD' => 'Created By Name Mod',
    'LBL_ASSIGNED_USER_NAME_OWNER' => 'Assigned User Name Owner',
    'LBL_ASSIGNED_USER_NAME_MOD' => 'Assigned User Name Mod',
    'LBL_TEAM_COUNT_OWNER' => 'Team Count Owner',
    'LBL_TEAM_COUNT_MOD' => 'Team Count Mod',
    'LBL_TEAM_NAME_OWNER' => 'Team Name Owner',
    'LBL_TEAM_NAME_MOD' => 'Team Name Mod',
    'LBL_ACCOUNT_NAME_OWNER' => 'Account Name Owner',
    'LBL_ACCOUNT_NAME_MOD' => 'Account Name Mod',
    'LBL_MODIFIED_USER_NAME' => 'Modified User Name',
    'LBL_MODIFIED_USER_NAME_OWNER' => 'Modified User Name Owner',
    'LBL_MODIFIED_USER_NAME_MOD' => 'Modified User Name Mod',
    'LBL_PORTAL_VIEWABLE' => 'Portal Viewable',
    'LBL_EXPORT_ASSIGNED_USER_ID' => 'Assigned User ID',
    'LBL_EXPORT_MODIFIED_USER_ID' => 'Modified By ID',
    'LBL_EXPORT_CREATED_BY' => 'Created By ID',
    'LBL_EXPORT_CREATED_BY_NAME' => 'Created By User Name',
    'LBL_EXPORT_ASSIGNED_USER_NAME' => 'Assigned User Name',
    'LBL_EXPORT_TEAM_COUNT' => 'Team Count',

    // SNIP
	'LBL_CONTACT_HISTORY_SUBPANEL_TITLE' => 'Related Contacts\' Emails',
);

?>
